@@ -41,6 +41,9 @@ class TheoConfig(ConfigExtension):
         # Theo comes with its own menu for web app
         config.setdefault('tailbone', 'menus', 'theo.web.menus')
 
+        # custom App Settings
+        config.setdefault('rattail', 'settings', 'theo.appsettings')
+
         # do we integrate w/ CORE-POS?
         if integrate_corepos(config):
             config.setdefault('rattail', 'model', 'theo.db.model_corepos')
@@ -53,6 +56,12 @@ class TheoConfig(ConfigExtension):
             config.setdefault('rattail.mail', 'emails', 'theo.emails.theo, theo.emails.catapult')
             config.setdefault('rattail.importing', 'versions.handler', 'theo.importing.versions_catapult:FromTheoToTheoVersions')
 
+        # do we integrate w/ LOC SMS?
+        elif integrate_locsms(config):
+            config.setdefault('rattail', 'model', 'theo.db.model_locsms')
+            config.setdefault('rattail.mail', 'emails', 'theo.emails.theo, theo.emails.locsms')
+            config.setdefault('rattail.importing', 'versions.handler', 'theo.importing.versions_locsms:FromTheoToTheoVersions')
+
         else: # no integration
             config.setdefault('rattail.mail', 'emails', 'theo.emails.theo')
 
@@ -65,3 +74,8 @@ def integrate_catapult(config):
 def integrate_corepos(config):
     return config.getbool('theo', 'integrate_corepos', default=False,
                           usedb=False)
+
+
+def integrate_locsms(config):
+    return config.getbool('theo', 'integrate_locsms', default=False,
+                          usedb=False)
