@@ -31,5 +31,3 @@ class FromTheoToTheoVersions(onager_base.FromRattailToRattailVersions):
     """
     Handler for Theo -> Theo "versions" data import
     """
-    host_title = "Theo"
-    local_title = "Theo (Versions)"
